@@ -22,6 +22,7 @@ import autocomplete_light
 
 
 class AutocompleteModel(autocomplete_light.AutocompleteModel):
+    """ Ensure that `.language()` is called. """
     def __init__(self, request=None, values=None):
         """
         Overridden init to call .language(). Note: this will replace the
@@ -34,9 +35,11 @@ class AutocompleteModel(autocomplete_light.AutocompleteModel):
 
 class AutocompleteModelBase(AutocompleteModel,
                             autocomplete_light.AutocompleteBase):
+    """ Drop-in replacement for AutocompleteModelBase """
     pass
 
 
 class AutocompleteModelTemplate(AutocompleteModel,
                                 autocomplete_light.AutocompleteTemplate):
+    """ Drop-in replacement for AutocompleteModelTemplate """
     pass
